/*
 * [AlignJavaCategory.java]
 *
 * Summary: Finite state automaton for parsing Java source sufficiently to align it in columns.
 *
 * Copyright: (c) 2007-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2007-04-07 initial version
 */
package com.mindprod.quoter;

/**
 * Finite state automaton for parsing Java source sufficiently to align it in columns.
 * <p/>
 * Various states for categorising
 * characters.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2007-04-07 initial version
 * @since 2007-04-07
 */
public enum AlignJavaCategory
    {
        /**
         * comma.
         */
        COMMA,
        /**
         * / comment introducer.
         */
        COMMENT,
        /**
         * new line.
         */
        NEWLINE,
        /**
         * ordinary \\p{Lower} A-z 0-9 punctuation.
         */
        ORDINARY,
        /**
         * single or double quote.
         */
        QUOTED,
        /**
         * space, tab.
         */
        WHITESPACE
    }
