/*
 * [DecodeURL.java]
 *
 * Summary: decode a URL. Convert % URL-encodings back to plain text.
 *
 * Copyright: (c) 2002-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.5 2009-02-26 add both Java string quoting and plain for Java search/regexes.
 */
package com.mindprod.quoter;

import static java.lang.System.*;

/**
 * decode a URL. Convert % URL-encodings back to plain text.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.5 2009-02-26 add both Java string quoting and plain for Java search/regexes.
 * @since 2002-06-19
 */
public final class DecodeURL extends Translator
    {
    /**
     * Decode an URL
     *
     * @param raw url to be decoded. Must not be null.
     *
     * @return translated text
     */
    public String process( String raw )
        {
        assert raw != null : "DecodeURL.process raw must not be null";
        try
            {
            return new java.net.URL( raw ).toURI().toString();
            }
        catch ( java.net.MalformedURLException e )
            {
            err.println( "invalid URL cannot be officially decoded" );
            }
        catch ( java.net.URISyntaxException e )
            {
            err.println( "invalid URL cannot be officially decoded" );
            }
        final int n = raw.length();
        // fail, do it in a mindless char-by-char way.
        StringBuilder sb = new StringBuilder( n );
        for ( int i = 0; i < n; i++ )
            {
            char c = raw.charAt( i );
            if ( c == '%' && i + 2 < n )
                {
                final String valueString = raw.substring( i + 1, i + 3 );
                c = ( char ) Integer.parseInt( valueString, 16 );
                i += 2;
                }
            sb.append( c );
            }
        return sb.toString();
        } // end process
    }
