/*
 * [EncodeURL.java]
 *
 * Summary: Eecode a URL. Convert awkward characters in a URL to % encodings.
 *
 * Copyright: (c) 2002-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.5 2009-02-26 add both Java string quoting and plain for Java search/regexes.
 */
package com.mindprod.quoter;

import java.net.MalformedURLException;
import java.net.URI;
import java.net.URISyntaxException;

/**
 * Eecode a URL. Convert awkward characters in a URL to % encodings.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.5 2009-02-26 add both Java string quoting and plain for Java search/regexes.
 * @since 2002-06-19
 */
public final class EncodeURL extends com.mindprod.quoter.Translator
    {
    /**
     * Encode an URL
     *
     * @param raw url to be encoded. Must not be null.
     *
     * @return translated text
     */
    public String process( String raw )
        {
        assert raw != null : "EncodeURL.process raw must not be null";
        try
            {
            return new URI( raw ).toURL().toString();
            }
        catch ( MalformedURLException e )
            {
            return "invalid URL cannot be encoded";
            }
        catch ( URISyntaxException e )
            {
            return "invalid URL cannot be encoded";
            }
        // encode it manually
        } // end process
    }
