/*
 * [ToJavaCharArrayLiteral.java]
 *
 * Summary: convert to Java char[] literal.
 *
 * Copyright: (c) 2002-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2002-06-19
 */
package com.mindprod.quoter;

/**
 * convert to Java char[] literal.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2002-06-19
 * @since 2002-06-19
 */
public final class ToJavaCharArrayLiteral extends Translator
    {
    private static final String[] trt;

    static
        {
        // translation table for char to Java literal string form.
        trt = new String[ 256 ];
        // initialize the trt array
        for ( int i = 0; i < 32; i++ )
            {
            trt[ i ] = "?";
            }
        for ( int i = 32; i < 127; i++ )
            {
            trt[ i ] = String.valueOf( ( char ) i ).intern();
            }
        for ( int i = 127; i < 161; i++ )
            {
            // control chars, should not be in Java source
            trt[ i ] = "?";
            }
        for ( int i = 161; i < 256; i++ )
            {
            trt[ i ] = "\\u" + Integer.toHexString( i + 0x10000 )
                    .substring( 1, 5 );
            }
        // override with chars that have special string representations
        trt[ 9 ] = "\\t";
        trt[ 10 ] = "\\n";
        trt[ 13 ] = "";/* discard \r */
        trt[ 26 ] = "";
        trt[ 34 ] = "\\\"";/* " -> \" */
        trt[ 39 ] = "'";/* ' left alone */
        trt[ 92 ] = "\\\\";/* \ -> \\ */
        trt[ 160 ] = " ";
        } // end  static init

    // instance init.
    {
    table = trt;
    }

    /**
     * Converts text to Java String literals by quoting dangerous characters e.g. " ==> \"
     *
     * @param raw raw text to be cooked. Must not be null.
     *
     * @return string with quoting embedded
     */
    public String process( String raw )
        {
        // handle high chars with \ u x x x x
        StringBuilder cooked = new StringBuilder( raw.length() * 5 );
        // enclose whole string in quotes
        cooked.append( "new char[] { " );
        for ( int i = 0; i < raw.length(); i++ )
            {
            char c = raw.charAt( i );
            if ( c == '\n' )
                {
                cooked.append( "'\\n',\n    " );
                }
            else if ( c < 256 )
                {
                cooked.append( "'" );
                cooked.append( table[ c ] );
                cooked.append( "', " );
                }
            else
                {
                // convert to \ u x x x x
                cooked.append( "'\\u" )
                        .append( Integer.toHexString( c + 0x10000 ) );
                cooked.append( "', " );
                }
            } // end for
        int length = cooked.length();
        if ( length >= 2 && cooked.substring( length - 2 ).equals( ", " ) )
            {// get rid of final ,space
            cooked.setLength( length - 2 );
            }
        else if ( length >= 6 && cooked.substring( length - 6 )
                .equals( ",\n    " ) )
            {// get rid of final ,\n----
            cooked.setLength( length - 6 );
            }
        cooked.append( " }" );
        return cooked.toString();
        }
    }
