/*
 * [Translator.java]
 *
 * Summary: Base class for various translate tables.
 *
 * Copyright: (c) 2002-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2002-06-19
 */
package com.mindprod.quoter;

/**
 * Base class for various translate tables.
 * <p/>
 * Each char may translate to another char or to a String of chars. Extended
 * must implement process, usually done by setting up table.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2002-06-19
 * @since 2002-06-19
 */
public abstract class Translator extends TextProcessor
    {
    /**
     * which translate table we are using right now.
     */
    String[] table;

    /**
     * no-arg constructor.
     */
    Translator()
        {
        // table must be filled in by implementor
        }

    /**
     * convert string, extender can override this default implementation.
     *
     * @param raw String to be converted
     *
     * @return converted string.  By default use table[] to translate char by char for 0..255 and leaves higher chars as
     * is.
     */
    public String process( String raw )
        {
        assert raw != null : "Translator.process raw must not be null";
        if ( raw.length() == 0 )
            {
            return "";
            }
        assert table != null : "table must be set by Translator implementor";
        StringBuilder cooked = new StringBuilder( raw.length() * 120 / 100 );
        for ( int i = 0; i < raw.length(); i++ )
            {
            char c = raw.charAt( i );
            if ( c < 256 )
                {
                cooked.append( table[ c ] );
                }
            else
                {
                // leave alone
                cooked.append( c );
                }
            } // end for
        return cooked.toString();
        } // end process
    }
