/*
 * [Trim.java]
 *
 * Summary: Trim lead/trail blanks off each line in buffer processed.
 *
 * Copyright: (c) 2002-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2002-06-19
 */
package com.mindprod.quoter;

import java.util.StringTokenizer;

/**
 * Trim lead/trail blanks off each line in buffer processed.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2002-06-19
 * @since 2002-06-19
 */
final class Trim extends TextProcessor
    {
    /**
     * Chops off leading and trailing spaces from each line.
     *
     * @param raw text to be chopped
     *
     * @return String representing the cooked output
     */
    String process( String raw )
        {
        // break clipboard into lines delimited by \n
        if ( raw == null )
            {
            return null;
            }
        else
            {
            StringBuilder stripped = new StringBuilder( raw.length() );
            StringTokenizer st = new StringTokenizer( raw, "\n", true );
            while ( st.hasMoreTokens() )
                {
                String token = st.nextToken();
                if ( token.equals( "\n" ) )
                    {
                    stripped.append( "\n" );
                    }
                else
                    {
                    stripped.append( token.trim() );
                    }
                } // end while
            return stripped.toString();
            }
        } // end process
    }
