/*
 * [TrimTrailing.java]
 *
 * Summary: Chops off trailing spaces from each line.
 *
 * Copyright: (c) 2002-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.5 2009-02-26 add both Java string quoting and plain for Java search/regexes.
 */
package com.mindprod.quoter;

import com.mindprod.common18.ST;

import java.util.StringTokenizer;

/**
 * Chops off trailing spaces from each line.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.5 2009-02-26 add both Java string quoting and plain for Java search/regexes.
 * @since 2002-06-19
 */
final class TrimTrailing extends TextProcessor
    {
    /**
     * Chops off trailing spaces from each line.
     *
     * @param raw text to be chopped
     *
     * @return String representing the cooked output
     */
    public String process( String raw )
        {
        // break clipboard into lines delimited by \n
        if ( raw == null )
            {
            return null;
            }
        // break clipboard into lines delimited by \n
        else
            {
            StringBuilder stripped = new StringBuilder( raw.length() );
            StringTokenizer st = new StringTokenizer( raw, "\n", true );
            while ( st.hasMoreTokens() )
                {
                String token = st.nextToken();
                if ( token.equals( "\n" ) )
                    {
                    stripped.append( "\n" );
                    }
                else
                    {
                    stripped.append( ST.trimTrailing( token ) );
                    }
                } // end while
            return stripped.toString();
            }
        } // end process
    }
